# 🚀 programmering.no | 🤓 matematikk.as
# S1 - Eksamen - 2023 Høst (Matematikk AS)
# Oppgave 2 c) Venstrehendte - Nøyaktig 3 venstrehendte elever i klassen 

import numpy as np

# Konstanter
p_vh_gutter                = 0.1       # Sannsynligheten for at gutt er venstrehendt (vh)
p_vh_jenter                = 0.08      # Sannsynligheten for at jente er vh
k_vh_elever                = 3         # Utvalget k med vh elever i klassen er nøyaktig 3
n_gutter                   = 13        # Gutter i klassen
n_jenter                   = 17        # Jenter i klassen
m_klasse                   = 10000000  # Mulige utfall (alle klasse-simuleringene)
m_gutter_klasse_liste      = list()    # Liste med mulige utfall (fra gutte-simuleringene)
m_jenter_klasse_liste      = list()    # Liste med mulige utfall (fra jente-simuleringene)
m_elever_klasse_liste      = list()    # Liste med mulige utfall (fra de kombinerte elev-simuleringene, se stegene nedenfor)
g_klasse_elever            = int()     # Gunstige utfall (fra simuleringene)
sannsyn_sim                = float()   # Sannsynligheten for at 3 elever i klassen er vh (simulert)

# Innstillinger
_blokk                     = 1         # 0: Av, 1: På, Skjul/debug deler av koden med if-blokker

# Definer tilfeldighets-generatoren (random number generator)
rng = np.random.default_rng()

if _blokk == -1:
    # Simulering steg-for-steg
    # 1. I denne simuleringen kan vi først tenke at vi har to adskilte
    #    gutte- og jente-klasser som sitter i hvert sitt nabo-rom
    # 2. Deretter gjør vi den samme simuleringen med guttene som i a) og b) oppg
    # 3. Simulerer at det er 10 % sannsynlighet for at en gutt er vh
    # 4. Denne gutten blir så enten vh eller ikke, 1 eller 0
    # 5. Gjør dette 13 ganger og får f.eks. 0, 1, 0, 0, 0, 0, 1, 0, ..., 0
    # 6. Teller hvor mange av de 13 guttene som ble vh, f.eks. 2
    # 7. Legger 2 i listen, [2]
    # 8. Gjør dette med 10 000 000 gutte-klasser, m_gutter_klasse_liste = [2, 0, 1, ..., 0]
    # 9. Gjentar de samme stegene med jentene, men med 8 % sannsynlighet for at en jente er vh 
    # 10. Får f.eks. m_jenter_klasse_liste = [1, 0, 1, ..., 1] fra jente-simuleringen
    # 11. Nå kan vi tenke oss at denne veggen mellom dem egentlig aldri fantes, og at de
    #     hele tiden satt i samme store klasserom
    # 12. De 10 000 000 simuleringene vi gjorde ble altså gjort som en kombinasjon (simulering nr 1
    #     for guttene er også simulering nr 1 for jentene)
    # 13. Vi kan derfor plusse de to listene element-vis slik (pluss sammen kolonnene)
    #         m_gutter_klasse_liste = [2, 0, 1, ..., 0]
    #       + m_jenter_klasse_liste = [1, 0, 1, ..., 1]
    #       = m_elever_klasse_liste = [3, 0, 2, ..., 1] <-- 10 000 000 kombinerte elev-simuleringer
    # 14. Dette er grunnen til at antall mulige utfall blir 10 000 000
    # 15. Deretter finner vi antall gunstige utfall og sannsynligheten på samme måte som i a) og b) oppg
    pass
m_gutter_klasse_liste = rng.binomial(n = n_gutter, p = p_vh_gutter, size = m_klasse)
m_jenter_klasse_liste = rng.binomial(n = n_jenter, p = p_vh_jenter, size = m_klasse)

# # Plusser sammen de to listene for å få en kombinert elev-liste med 10 000 000 mulige utfall
m_elever_klasse_liste = m_gutter_klasse_liste + m_jenter_klasse_liste

# Tell gunstige utfall (alle kobinerte klasser med nøyaktig 3 vh)
g_klasse_elever = sum(m_elever_klasse_liste == k_vh_elever)

# Definisjonen av sannsynlighet gir P(VH) = g / m, der hendelsen VH: "Elev i klassen er vh"
sannsyn_sim = g_klasse_elever / m_klasse

# Gang med 100 for prosent og rund av til f.eks. 1 eller 0 (None) desimaler
sannsyn_sim = round(sannsyn_sim * 100, 2)

# Lag svar-setninger
svar_1 = "Sannsynligheten for at det er nøyaktig 3 venstrehendte elever i klassen er:"
svar_2 = f"P(X >= {k_vh_elever}) = {sannsyn_sim} %"

# Print svar-setninger
print("")
print(svar_1)
print("")
print(svar_2)



# 🚀 programmering.no | 🤓 matematikk.as
# S1 - Eksamen - 2023 Høst (Torodd)
# Oppgave 1 c) Sofa-produksjon til møbelfabrikk - Minst salgspris 

from sympy import Symbol, diff, Eq, Reals, solveset

_blokk = 1

if _blokk == 1:

    # definerer symboler
    x = Symbol("x")
    a = Symbol("a")

    # definerer K(x) og I(x). Ny pris = a.
    K = 0.041*x**2 + 17*x + 103
    I = a*x

    # Bestemmer O(x)
    O = I - K

    # Finn likning for ekstremalpunktet til O
    vs = diff(O, x)
    hs = 0

    # set opp likninga, og løyser ho
    likning = Eq(vs, hs)
    løysing = solveset(likning, x, domain=Reals)
    løysing # <--- Slett?

if _blokk == 1:

    # definerer x-verdien til ekstremalpunktet uttrykt ved a
    x_topp = 12.2*a - 207.3

    # finn O(x_topp)
    nyO = O.subs(x, x_topp)

    # Sett opp likning for O(x_topp)=1000
    vs = nyO
    hs = 1000

    # set opp likninga, og løyser ho
    likning = Eq(vs, hs)
    løysing = solveset(likning, a, domain=Reals)

if _blokk == 1:

    a1 = 3.55
    a2 = 30.45

    x1 = x_topp.subs(a, a1).evalf()
    x2 = x_topp.subs(a, a2).evalf()

    print(f"Pris på {a1*1000} kr gjev x = {x1:.0f}")
    print(f"Pris på {a2*1000} kr gjev x = {x2:.0f}")



# 🚀 programmering.no | 🤓 matematikk.as
# - Eksempel på NoneType

# Variabler
bruker_aktiv = None

# Ser om en bruker er registrert og aktiv
if bruker_aktiv == None:
    print("Bruker eksisterer ikke")
if bruker_aktiv == True:
    print("Bruker er aktiv")
if bruker_aktiv == False:
    print("Bruker er ikke aktiv")



# 🚀 programmering.no | 🤓 matematikk.as
# - Hvordan bruke indeks for å få tak i en bokstav (char)

# Variabler
pyt = "Python 🐍"

# Print
print(pyt[0])
print(pyt[1])
print(pyt[2])
print(pyt[3])
print(pyt[4])
print(pyt[5])
print(pyt[6])
print(pyt[7])



# 🚀 programmering.no | 🤓 matematikk.as
# S1 - Eksamen - 2023 Høst (Matematikk AS)
# Oppgave 2 b) Venstrehendte - Sannsynlighets-relasjoner - P(X <velg relasjon> k) > sannsyn_gitt 
# - Oppgave-teksten har antageligvis en feil (som dette programmet fikser)
# - Feilen er at ordet "MINST" ikke er tatt med
#   - "Hvor mange gutter må det (MINST) være i en klasse dersom
#      sannsynligheten for at minst tre av guttene er
#      venstrehendte, skal være større enn 20 prosent?"
# - Grunnen til at dette blir feil, er at man uten ordet "MINST" bare kunne sagt
#   et veldig stort antall gutter (f.eks. 1000 eller "uendelig")
# - Fordi hvis man kun spør om "hvor mange gutter det må være for at
#   denne sannsynligheten skal være større enn 20 %", så vil jo denne
#   sannsynligheten selvfølgelig raskt bli mye større enn 20 % når det er veldig
#   mange gutter i klassen, og det kun er snakk om 3 venstrehendte der
# - Derfor er det fornuftig å heller finne det minste antallet gutter i klassen
#   (grensetilfelle), som gjør at denne sannsynligheten akkurat blir større enn 20 %

import numpy as np

# Konstanter
_blokk             = 0         # 0: Av, 1: På, Skjul/debug deler av koden med if-blokker
p_vh               = 0.1       # Sannsynligheten for at gutt er venstrehendt (vh)
k_vh               = 3         # Utvalget k med vh i klassen
n_klasse           = 1         # Gutter i klassen (starter på 1 eller k_vh)
m_klasse           = 1000      # Mulige utfall (alle klasse-simuleringene)
m_klasse_liste     = list()    # Liste med mulige utfall (fra simuleringene)
g_klasse           = int()     # Gunstige utfall (fra simuleringene)
sannsyn_gitt       = 0.2       # Sannsynligheten for at k gutter i klassen er vh (gitt i oppg)
sannsyn_gitt_rel   = ">="      # Velg relasjon for sannsyn_gitt ("==", ">=", ">", "<=", "<")
sannsyn_sim        = float()   # Sannsynligheten for at k gutter i klassen er vh (simulert)
n_svar_rel         = str()     # Relasjon for antall vh i svaret (regnes ut i koden)

# Definer tilfeldighets-generatoren (random number generator)
rng = np.random.default_rng()

# Regner ut sannsynligheten for k antall vh i en klasse med n_klasse gutter (se while-løkke)
def sannsynlighet_for(n_klasse, s_rel = sannsyn_gitt_rel):

    # Simulering steg-for-steg
    if _blokk == 1:
        # 1. n_klasse starter på 1 og kan øke
        # 2. Etter første simulering sammenlignes sannsyn_sim med sannsyn_gitt
        # 3. Hvis sannsyn_sim < sannsyn_gitt øker n_klasse med 1
        # 4. Da gjøres simuleringen om igjen med den nye verdien for n_klasse
        # 5. Simulerer at det er p_vh sannsynlighet for at en gutt er vh
        # 6. Denne gutten blir så enten vh eller ikke, 1 eller 0
        # 7. Gjør dette n_klasse ganger og får f.eks. 0, 0, 1, 0 og 1 (hvis n_klasse er 5)
        # 8. Teller hvor mange av de n_klasse som ble vh, f.eks. 2
        # 9. Legger 2 i listen, [2]
        # 10. Gjør dette med m_klasse klasser, [2, 0, 0, ..., 1]
        # 11. m_skole_liste får dermed alle utfallene (fra simuleringen)
        pass
    m_klasse_liste = rng.binomial(n = n_klasse, p = p_vh, size = m_klasse)

    # Tell gunstige utfall og velg riktig relasjon til svaret
    if s_rel == "==":                 g_klasse = sum(m_klasse_liste == k_vh); n_svar_rel = "nøyaktig"
    if s_rel == ">=" or s_rel == ">": g_klasse = sum(m_klasse_liste >= k_vh); n_svar_rel = "minst"
    if s_rel == "<=" or s_rel == "<": g_klasse = sum(m_klasse_liste <= k_vh); n_svar_rel = "maksimalt"

    # Definisjonen av sannsynlighet gir P(VH) = g / m, der hendelsen VH: "Gutt på skolen er vh"
    sannsyn_sim = g_klasse / m_klasse

    # Returnerer en liste med sannsynlighet og relasjon
    return [sannsyn_sim, n_svar_rel]

# While-løkke steg-for-steg
if _blokk == 1:
    # 1. En endring fra 02_oppg_2_b er at betingelsen i løkken nå er to-delt
    #    1.1 For ">=", ">", "==": sannsyn_sim går fra 0 opp til sannsyn_gitt
    #    1.2 For "<=", "<"      : sannsyn_sim går fra 1 ned til sannsyn_sim
    # 2. Løkken kaller først f_sannsynlighet_for() med to argumenter
    #    2.1. sannsyn_gitt_rel (valgfri/har default): ("==", ">=", ">", "<=", "<")
    #    2.2. n_klasse (obligatorisk)               : nåværende gutter i klassen
    # 3. sannsynlighet_for() returnerer to variabler (i en liste)
    #    3.1 sannsynlighet_for()[0]: sannsyn_sim
    #    3.2 sannsynlighet_for()[1]: svar_rel (relasjonen i svaret)
    # 4. Hvis f.eks. sannsyn_sim < sannsyn_gitt (betingelsen), så øker n_gruppe med 1
    # 5. Isåfall kaller løkken sannsynlighet_for() om igjen
    # 6. Løkken vil da repeterer dette til sannsyn_sim >= sannsyn_gitt (betingelsen brytes)
    pass
while   (((sannsyn_gitt_rel == ">=" or sannsyn_gitt_rel == ">" or sannsyn_gitt_rel == "==") and
            (sannsynlighet_for(n_klasse, sannsyn_gitt_rel)[0] < sannsyn_gitt))
    or   ((sannsyn_gitt_rel == "<=" or sannsyn_gitt_rel == "<") and
            (sannsynlighet_for(n_klasse, sannsyn_gitt_rel)[0] > sannsyn_gitt))):

    # n_klasse øker med 1 hver gang løkken (og simuleringen) kjøres
    n_klasse += 1

# Kaller sannsynlighet_for() en ekstra gang med forrige klasse_n for å få relasjonen til svaret
n_svar_rel = sannsynlighet_for(n_klasse - 1, sannsyn_gitt_rel)[1]

# Gang med 100 for prosent og rund av til f.eks. 1 eller 0 (None) desimaler
sannsyn_gitt = round(sannsyn_gitt * 100, None)

# Lag svar-setninger
svar_1 = f"Når det skal være større enn {sannsyn_gitt} % sannsynlighet for at"
svar_2 = f"{n_svar_rel} {k_vh} gutter i klassen er venstrehendte,"
svar_3 = f"så må det være {n_svar_rel} {n_klasse} gutter i klassen"

# Print svar-setninger
print("")
print(svar_1)
print(svar_2)
print(svar_3)



# 🚀 programmering.no | 🤓 matematikk.as
# - Regn ut summen av elementene i en liste med sum()

# Input
liste = [10, 20, 30]

# Sum
sum = sum(liste)

# Print
print(f"Liste                : {liste}")
print(f"Summen av elementene : {sum}")



# 🚀 programmering.no | 🤓 matematikk.as
# - Loop gjennom elementene i listen med indeks

# Variabler
liste = ["A", "B", "C"]

# For hver iterasjon printes neste element
for i in range(len(liste)):
    print(liste[i])



# 🚀 programmering.no | 🤓 matematikk.as
# - Gyldige variabelnavn

# Variabler
små         = "små bokstaver"
STORE       = "STORE BOKSTAVER"
tall_42     = 42
_sym_underscore = "_data_"

# Print
print(små)



# 🚀 programmering.no | 🤓 matematikk.as
# S1 - Eksamen - 2023 Høst (Matematikk AS)
# Oppgave 1 b) Sofa-produksjon til møbelfabrikk - Størst overskudd 
# - Løser oppgaven med CAS i Python
# - Kopier kommandoene i terminalen og importer pakkene 
#   $ pip install numpy
#   $ pip install sympy
#   $ pip install matematikk

from numpy import polyfit
from sympy import Eq, diff, Reals, solveset, Symbol

# Variabler
x            = Symbol("x")       # Produksjons-mengden x
x_max        = float()           # Produksjonsmengden som gir størst overskudd
K            = Symbol("K")       # Polynomets navn (vs)
grad         = 2                 # Polynomets grad
poly         = Symbol("poly")    # Polynomet (vs og hs)
x_liste      = [                 # Liste med x-verdier
    10,
    25,
    40,
    70,
    100,
    140,
    180]
y_liste      = [                 # Liste med y-verdier
    270,
    550,
    870,
    1500,
    2200,
    3300,
    4500]
O            = Symbol("O")       # Overskudds-funksjonen
dO           = Symbol("dO")      # Den deriverte av overskudds-funksjonen
rund         = 2                 # -1: Ingen avrunding, 0: Eks: 123.0, n > 0: n siffer etter desimaltegnet, None: Heltall
_blokk       = 1                 # 0: Av, 1: På, Skjul/debug deler av koden med if-blokker

# Definerer funksjoner
def reggis(variabel = Symbol(""),
           grad     = int(),
           x_liste  = list(),
           y_liste  = list(),
           rund     = -1):

    # - Lager polynom-funksjon av valgfri grad vha. regresjon (CAS)

    # Variabler
    _koeff_liste       = list()                # Liste med koeffesienter i fra polyfit()
    _koeff             = float()               # Polynomets koeffisienter
    _ledd              = Symbol("_ledd")       # Polynomets ledd
    _ledd_grad         = int()                 # Polynomets ledd inkludert grad
    _uttrykk           = Symbol("_uttrykk")    # Polynomets uttrykk (hs)

    # polyfit() returnerer en liste med regresjons-koeffesientene
    _koeff_liste = polyfit(x_liste, y_liste, grad)

    # Hver iterasjon lager det neste leddet i polynomet
    for i in range(len(_koeff_liste)):

        # - På 1. iterasjon må _uttrykk nulles ut slik at det ikke blir en
        #   egen variabel i uttrykket, f.eks. "_uttrykk + 0.04*x**2 + 17.05*x + 102.7"
        if i == 0: _uttrykk = 0

        # Runder av koeffesienten
        if rund == -1: _koeff = _koeff_liste[i]
        if rund != -1: _koeff = round(_koeff_liste[i], rund)

        # Lager leddene i fra størst til minst grad
        _ledd_grad = grad - i

        # Formaterer leddene
        if _ledd_grad >= 2: _ledd = _koeff * variabel**_ledd_grad
        if _ledd_grad == 1: _ledd = _koeff * variabel
        if _ledd_grad == 0: _ledd = _koeff

        # Legger det nye leddet til polynomet
        _uttrykk += _ledd

    return _uttrykk

# a) Finn O(x)
if _blokk == 1:

    # Lager polynom-funksjon av valgfri grad vha. regresjon (CAS)
    K = reggis(variabel = x,
               grad     = grad,
               x_liste  = x_liste,
               y_liste  = y_liste,
               rund     = rund)

    # Svar-setninger
    svar_a_liste = list()
    svar_a_liste.append(f"")
    svar_a_liste.append(f"Oppg a)")
    svar_a_liste.append(f"")
    svar_a_liste.append(f"- Med regresjon fra numpy (polyfit) ser vi at hvis bedriften")
    svar_a_liste.append(f"  produserer x enheter, så vil")
    svar_a_liste.append(f"")
    svar_a_liste.append(f"    {K}")
    svar_a_liste.append(f"")
    svar_a_liste.append(f"  være en god model for det måntlige overskuffet (i tusen kroner)")

    # Print svar-setninger
    for svar in svar_a_liste: print(svar)

# b) Størst overskudd
if _blokk == 1:

    # Definerer uttrykket for overskudds-funksjonen, O
    O = -0.041*x**2 + 11*x - 103

    # Deriverer O mhp. x og får dO = 11 - 0.082*x
    dO = diff(O, x) # O'(x)

    # Lager likningen dO = 0 med Eq(vs, hs) 
    likning = Eq(dO, 0)

    # Løser likningen for x med solveset() og får løsnings-settet {134.146341463415}
    x_topp_set = solveset(likning, x, domain=Reals) # Løsnings-domene i ℝ (Reals)

    # Henter elementet i fra løsnings-settet, 134.146341463415
    x_max = x_topp_set.args[0]

    # Runder av 134.146341463415 -> 134
    x_max = round(x_max, None)

    # Svar-setninger
    svar_b_liste = list()
    svar_b_liste.append(f"")
    svar_b_liste.append(f"Oppg b)")
    svar_b_liste.append(f"")
    svar_b_liste.append(f"- Negativ a-koeffisient gir et toppunkt på O")
    svar_b_liste.append(f"- Produksjonsmengden x = {x_max} gir størst overskudd")

    # Print svar-setninger
    for svar in svar_b_liste: print(svar)



# 🚀 programmering.no | 🤓 matematikk.as
# - Bytt første og siste element i en liste

# Verdier
liste = [1, 2, 3, 4, 5]

# Print
print(f"Liste: {liste}")

# Kopier det første el til en midlertidig tmp-variabel
el_tmp = liste[0]

# Bytt det første el i listen med det siste
liste[0] = liste[-1]

# Bytt det siste el med tmp-variabelen
liste[-1] = el_tmp

# Print
print(f"Liste: {liste}")



# Versjon: 0.0.157 YOYO

# '''
# numpy()
from numpy import(
    polyfit
    )

# sympy()
from sympy import (
    ConditionSet,
    core,
    diff,
    Eq,
    FiniteSet,
    Intersection,
    ln,
    log,
    nsolve,
    Reals,
    solve,
    solveset,
    Symbol
    )

# deriver()
from ._exports.def_deriver_mas import (
    deriver,

    # Alias > 1
    derivert,
    momentan_vekst,
    momentan_vekstfart
    ) 

# vekstfaktor_cas()
from ._exports.def_vekstfaktor_cas import (
    vekstfaktor_cas
    )

# reggis()
from ._exports.def_reggis_matematikk_mas import (
    reggis,

    # Alias > 1
    reggis_cas,
    regresjon,
    regresjon_cas,
    regresjon_polynom,
    regresjon_polynom_cas,

    # Alias > 2
    cas_regresjon,
    cas_regresjon_polynom,
    regresjon_polynom_cas
    )

# superlos()
from ._exports.def_superlos_matematikk_mas import (
    superløs,

    # Alias > 1
    los,
    losning,
    løs,
    løsning,
    superlos,
    super_los,
    super_løs,

    # Alias > 2
    los_super,
    løs_super
    )

# ekstremalpunkt_max()
from ._exports.def_ekstremalpunkt_max_mas import (
    ekstremalpunkt_max,

    # Alias > 1
    ekstremalpunkt_maks,
    ekstremalpunkt_maksimalt,
    toppunkt

    # Alias > 2 > ...
    )

# overskudd_max()
from ._exports.def_overskudd_max_mas import (
    overskudd_max,

    # Alias > 1
    overskudd_maks,
    overskudd_maksimalt,
    overskudd_mest,
    overskudd_storst,
    overskudd_størst,

    # Alias > 2
    maks_overskudd,
    maksimalt_overskudd,
    mest_overskudd,
    storst_overskudd,
    størst_overskudd
    )
# '''



# 🚀 programmering.no | 🤓 matematikk.as
# S1 - Eksamen - 2023 Høst (Torodd)
# Oppgave 2 c) Venstrehendte - Nøyaktig 3 venstrehendte elever i klassen 

import numpy as np

# definerer tilfeldighetsgeneratoren
rng = np.random.default_rng()

# tal simuleringar
N = 10000000

# trekk venstrehendte jenter og gutar for seg
jenter = rng.binomial(n=17, p=0.08, size=N)
gutar = rng.binomial(n=13, p=0.10, size=N)

# finn totalt tal venstrehendte kvart forsøk
venstrehendte = jenter + gutar

# tel opp gunstige og finn sannsynet.
gunstige = sum(venstrehendte == 3)
sannsyn = gunstige / N
print(f"P(nøyaktig tre venstrehendte) = {sannsyn:.4f}")



# 🚀 programmering.no | 🤓 matematikk.as
# S1 - Eksamen - 2023 Høst (Torodd)
# Oppgave 3 c) Sparekonto - År før totalt innskudd er fordoblet 

from sympy import Symbol, Eq, nsolve

# definerer symboler
x = Symbol("x")

# Finn likning
vs = 1.03**x + 1.06**x
hs = 4

# set opp likninga, og løyser ho numerisk
likning = Eq(vs, hs)
løysing = nsolve(likning, x, 1)
print(løysing)



# 🚀 programmering.no | 🤓 matematikk.as
# - Oversikt over datatypene i Python

# Variabler
eks_str          = str()
eks_int          = int()
eks_float        = float()
eks_complex      = complex()
eks_list         = list()
eks_tuple        = tuple()
eks_range        = range(0, 10) # Må defineres med to intervall-grenser
eks_dict         = dict()
eks_set          = set()
eks_fronzenset   = frozenset()
eks_bool         = bool()
eks_bytes        = bytes()
eks_bytearray    = bytearray()
eks_memoryview   = memoryview(eks_bytearray) # Må defineres med et byte-objekt
eks_none         = None

# Print datatype
print("Datatypene i Python::")
print(type(eks_str))
print(type(eks_int))
print(type(eks_float))
print(type(eks_complex))
print(type(eks_list))
print(type(eks_tuple))
print(type(eks_range))
print(type(eks_dict))
print(type(eks_set))
print(type(eks_fronzenset))
print(type(eks_bool))
print(type(eks_bytes))
print(type(eks_bytearray))
print(type(eks_memoryview))
print(type(eks_none))



# 🚀 programmering.no | 🤓 matematikk.as
# - Finn antall siffer i et heltall

# Verdier
n = 371

# Regner ut antall siffer i heltallet n
def siffer_antall_len(n):

    # Eks: str(371) -> "371" => len("371") = 3 (siffer)
    siffer_ant = len(str(n))

    return siffer_ant

# Antall siffer i heltallet n
siffer_ant = siffer_antall_len(n)

# Print
print(f"Antall siffer i {n} er: {siffer_ant}")



# 🚀 programmering.no | 🤓 matematikk.as
# - Del en liste opp i mindre lister med n elementer i hver liste

# Input
liste = input("Listen som skal deles opp: ") # Husk [ ] og '', f.eks. ['gull', 'sølv', 'bronse']
n_deler = input("Antall elementer per liste: ")

# Enkel funksjon som klipper opp inp-str til liste med str-el
def str_til_str_liste(str_liste = list()):

    str_ferdig_liste = list()
    el = str()
    for i in range(len(str_liste)):
        if str_liste[i] == " ": pass
        elif str_liste[i] == "[": pass
        elif str_liste[i] == "]":
            str_ferdig_liste.append(el)
            el = ""
        elif str_liste[i] == ",":
            str_ferdig_liste.append(el)
            el = ""
        elif str_liste[i] == '"': pass # Fjerner doble hermetegn ("")
        elif str_liste[i] == "'": pass # Fjerner doble hermetegn ('')
        else: el += str_liste[i]
    return str_ferdig_liste

# Input-string endres til liste med str-el
liste = str_til_str_liste(liste)

# Del opp listen i del-lister med n elementer i hver del-liste
def oppdeling_lister_comprehension(liste, n_deler):

    n_deler    = int(n_deler)
    del_lister = []

    # Lager del-listene med list comprehension
    del_lister = [liste[i : i + n_deler] for i in range(0, len(liste), n_deler)]

    return del_lister

# Del-lister
del_lister = oppdeling_lister_comprehension(liste, n_deler)

# Print
print(f"Del-lister (hele): {del_lister}")
print("Del-lister (en og en):")
for del_liste in del_lister:
	print(f"{del_liste}")



# 🚀 programmering.no | 🤓 matematikk.as
# - Finn antall siffer i et heltall

# Input
n = input("Tall: ")

# Regner ut antall siffer i heltallet n
def siffer_antall_divisjon(n):

    # Type cast inp-str -> int
    n = int(n)

    # Nullstill
    siffer_ant = 0

    # Itererer frem antall siffer (stop når n = 0)
    while n != 0:
        siffer_ant += 1   # Øk antall siffer med 1 for hver iterasjon
        n = int(n / 10)   # Eks: 371 (3 siffer) / 10 = 37.1 => int(37.1) = 37 (2 siffer) => ... => int(3.7) = 3 (1 siffer)

    return siffer_ant

# Antall siffer i heltallet n
siffer_ant = siffer_antall_divisjon(n)

# Print
print(f"Antall siffer i {n} er: {siffer_ant}")



# 🚀 programmering.no | 🤓 matematikk.as
# - Finn negative tall i en liste

# Verdier
liste = input("Finn negative tall i listen: ") # Husk [ ], f.eks. [-2, -1, 3, 15]

# Enkel funksjon som klipper opp inp-str til liste med int-el
def str_til_int_liste(str_liste = list()):

    int_liste = list()
    el = str()
    for i in range(len(str_liste)):
        if str_liste[i] == " ": pass
        elif str_liste[i] == "[": pass
        elif str_liste[i] == "]":
            int_liste.append(int(el))
            el = ""
        elif str_liste[i] == ",":
            int_liste.append(int(el))
            el = ""
        else: el += str_liste[i]
    return int_liste

# Funksjon for å finne negative tall i en liste
def negative_tall_liste(liste):

	# Nullstill
	negative_tall_liste = list()

	# Itererer gjennom listen
	for tall in liste:

		# Legg tallet i listen hvis det er negativt
		if tall < 0:
			negative_tall_liste.append(tall)

	return negative_tall_liste

# Input-string endres til liste med int-el
liste = str_til_int_liste(liste)

# Negative tall
negative_tall_liste = negative_tall_liste(liste)

# Print
print(f"Original liste          : {liste}")
print(f"Liste med negative tall : {negative_tall_liste}")



# 🚀 programmering.no | 🤓 matematikk.as
# - Finn produktet av alle elementene i en liste

# Verdier
liste = [2, 4, 10]

# Funksjon som multipliserer alle el i en liste
def produkt_liste(liste):

	# Sett startverdi som 1
	produkt = 1

	# Oppdater sum for hver iterasjon
	for el in liste:
		produkt *= el

	return(produkt)

# Sum
produkt = produkt_liste(liste)

# Print
print(f"Liste                   : {liste}")
print(f"Produktet av elementene : {produkt}")



# 🚀 programmering.no | 🤓 matematikk.as
# S1 - Eksamen - 2023 Høst (Matematikk AS)
# Oppgave 2 a) Venstrehendte - Minst 25 venstrehendte gutter 

import numpy as np

# Konstanter
p_vh               = 0.1       # Sannsynligheten for at gutt er venstrehendt (vh)
k_vh               = 25        # Utvalget k med vh på skolen er 25 eller større
n_skole            = 280       # Gutter på skolen
m_skole            = 10000000  # Mulige utfall (alle skole-simuleringene)
m_skole_liste      = list()    # Liste med mulige utfall (fra simuleringene)
g_skole            = int()     # Gunstige utfall (fra simuleringene)
sannsyn_sim        = float()   # Sannsynligheten for at k gutter på skolen er vh (simulert)

# Definer tilfeldighets-generatoren (random number generator)
rng = np.random.default_rng()

# Simulering steg-for-steg
# 1. Simulerer først at det er 10 % sannsynlighet for at en gutt er vh
# 2. Denne gutten blir så enten vh eller ikke, 1 eller 0
# 3. Gjør dette 280 ganger og får f.eks. 0, 1, 0, 0, 0, 0, 1, 0, ..., 1
# 4. Teller hvor mange av de 280 som ble vh, f.eks. 27
# 5. Legger 27 i listen, [27]
# 6. Gjør dette med 10 000 000 skoler, [27, 25, 29, ..., 24]
# 7. m_skole_liste får dermed alle utfallene (fra simuleringen)
m_skole_liste = rng.binomial(n = n_skole, p = p_vh, size = m_skole)

# Tell gunstige utfall (alle skoler med 25 eller flere vh)
g_skole = sum(m_skole_liste >= k_vh)

# Definisjonen av sannsynlighet gir P(VH) = g / m, der hendelsen VH: "Gutt på skolen er vh"
sannsyn_sim = g_skole / m_skole

# Gang med 100 for prosent og rund av til f.eks. 1 eller 0 (None) desimaler
sannsyn_sim = round(sannsyn_sim * 100, 1)

# Lag svar-setninger
svar_1 = "Sannsynligheten for at det er minst 25 venstrehendte gutter på skolen er:"
svar_2 = f"P(X >= {k_vh}) = {sannsyn_sim} %"

# Print svar-setninger
print("")
print(svar_1)
print("")
print(svar_2)



# 🚀 programmering.no | 🤓 matematikk.as
# S1 - Eksamen - 2023 Høst (Udir)
# Oppgave 5) Grensekostnaden K'(x) til bedrift 
 
def K(x):
	return 0.1*x**2 + 100*x + 9000

grense = 200
h = 0.0001
a = 1

while (K(a + h) - K(a))/h < grense:
    a = a + 1

print(a)



# 🚀 programmering.no | 🤓 matematikk.as
# S1 - Eksamen - 2023 Høst (Torodd)
# Oppgave 1 a) Sofa-produksjon til møbelfabrikk - Finn O(x) 

import numpy as np

# definerer variablar for x og y
x = np.array([10, 25, 40, 70, 100, 140, 180])
y = np.array([270, 550, 870, 1500, 2200, 3300, 4500])

# finn koeffesientane med regresjon (andregradsfunksjon)
a, b, c = np.polyfit(x, y, 2)

print(f"K(x) = {a:.3f}x^2 + {b:.0f}x + {c:.0f}")



# 🚀 programmering.no | 🤓 matematikk.as
# - Loop gjennom elementene i listen med element-variabel

# Variabler
liste = ["A", "B", "C"]

# For hver iterasjon printes neste element
for el in liste:
    print(el)



# 🚀 programmering.no | 🤓 matematikk.as
# - Regn ut produktet av to matriser med numpy

import numpy as np

# Matrise A (3x3)
matrise_A = np.array(
                    [[12, 7, 3],
                    [ 4,  5, 6],
                    [ 7,  8, 9]])

# Matrise B (3x4)
matrise_B = np.array(
                    [[5, 8, 1, 2],
                    [ 6, 7, 3, 0],
                    [ 4, 5, 9, 1]])

# Produktet av A og B (3x3 * 3x4 => 3x4)
matrise_produkt = np.dot(matrise_A, matrise_B)

# Print radene i produktet (3x4)
for r in matrise_produkt:

    # Rad
	print(r)



# 🚀 programmering.no | 🤓 matematikk.as
# Sinus 1T (2020) - BrettBoka - 1.5 Formler (s. 28) 
# Eksempel 1.5 a) og b) Vindpark I (boken)

from math import pi
radius = 58.5
vindstyrke = 5
areal = pi*radius**2
effekt = 0.0003*areal*vindstyrke**3
print("Arealet er", round(areal), "kvadratmeter.")
print("Effekten er", round(effekt), "kW.")



# 🚀 programmering.no | 🤓 matematikk.as
# S1 - Eksamen - 2023 Høst (Torodd)
# Oppgave 3 a) Sparekonto - Finn innskuddet til Per 

from sympy import Symbol, Eq, Reals, solveset

# definerer symboler
x = Symbol("x")

# Finn likning
vs = x * 1.03**8
hs = 30000

# set opp likninga, og løyser ho
likning = Eq(vs, hs)
løysing = solveset(likning, x, domain=Reals)

print(løysing)



# 🚀 programmering.no | 🤓 matematikk.as
# - Finn det største elementet i en liste med sort()

# Verdier
liste = [10, 7000, 20, 3, 400]

# Funksjon for å finne max el i en liste med sort()
def maksimum_sort(liste):

	# Sorterer listen i stigende rekkefølge
	liste.sort()

	# Max el er siste el i listen (index -1)
	max = liste[-1]

	return max

# Maksimum
max = maksimum_sort(liste)

# Print
print(f"Liste             : {liste}")
print(f"Maksimum i listen : {max}")



# 🚀 programmering.no | 🤓 matematikk.as
# - Se om listen er sortert i stigende eller synkende rekkefølge (monotonisk)
# - Kopierer, sorterer og sammenligner med den originale listen

# Input
liste_1 = [1, 2, 3, 4, 5]
liste_2 = [1, 2, 3, 5, 4]

# Funksjon som ser om listen er monotonisk eller ikke
def er_liste_monotonisk_sort(liste):

    # Kopier alle el til de to listene
	stigende_liste = liste.copy()
	synkende_liste = liste.copy()

	# Sorter begge listene (stigende verdier)
	stigende_liste.sort()
	synkende_liste.sort()

	# Reverser den ene (synkende verdier)
	synkende_liste.reverse()

	# Hvis listen er enten stigende eller synkende
	if stigende_liste == liste or synkende_liste == liste: return True

    # Hvis listen er hverken stigende eller synkende
	else: return False

# Monotonisk eller ikke
er_monotonisk_1 = er_liste_monotonisk_sort(liste_1)
er_monotonisk_2 = er_liste_monotonisk_sort(liste_2)

# Liste 1
print(f"Liste 1: {liste_1}")
if er_monotonisk_1 == True:
	print(f"Er liste 1 sortert? Ja")
if er_monotonisk_1 == False:
	print(f"Er liste 1 sortert? Nei")

# Liste 2
print(f"Liste 2: {liste_2}")
if er_monotonisk_2 == True:
	print(f"Er liste 2 sortert? Ja")
if er_monotonisk_2 == False:
	print(f"Er liste 2 sortert? Nei")



# 🚀 programmering.no | 🤓 matematikk.as
# - Finn partallene i en liste med mod 2

# Verdier
liste = [-3, -2.5, -1, 0, 1, 2, 3, 4, 5, 6]

# Funksjon for å finner partallene i en liste
def partall_liste_mod(liste):

	# Nullstill
	partall_liste = list()

	# Itererer gjennom listen
	for tall in liste:

		# Hvis resten av divisjon med 2 er 0, så er tallet et partall
		if tall % 2 == 0:
			partall_liste.append(tall)

	return partall_liste

# Partall-liste
partall_liste = partall_liste_mod(liste)

# Print
print(f"Original liste : {liste}")
print(f"Partall-liste  : {partall_liste}")



# 🚀 programmering.no | 🤓 matematikk.as
# S1 - Eksamen - 2023 Høst (Matematikk AS)
# Oppgave 6 a) Tredjegradsfunksjon - Påstand 1: Grafen f har minst ett ekstremalpunkt 

from sympy import ConditionSet, core, diff, Eq, FiniteSet, Intersection, nsolve, Reals, solve, solveset, Symbol

# Definerer funksjoner
def superløs(variabel = Symbol(""),
             vs       = Symbol(""),
             hs       = Symbol(""),
             likning  = list(),
             rund     = -1,
             debug    = -1):

    vis_datatype = True
    losning_set, losning_set_sub = set(), set()
    losning_liste, losning_element, losning_rund_liste, losning_ut = list(), list(), list(), list()
    losning_rund_status, sett_typ, likn_ant, los_ant, _v_avrund_typ = str(), str(), str(), str(), str()
    losning_rund = float()

    if type(likning) != list: likning_tmp = likning; likning = []; likning.append(likning_tmp)

    if len(likning) == 0:
        likn_ant = "En likning"
        if type(variabel) == type(list()): variabel = variabel[0]
        if type(vs) != core.mul.Mul and type(vs) == type(list()): vs = vs[0]
        if type(hs) != core.mul.Mul and type(hs) == type(list()): hs = hs[0]
        _likning = Eq(vs, hs); losning_set = solveset(_likning, variabel, domain = Reals)

        if len(likning) == 0 and type(losning_set) == FiniteSet:
            sett_typ = "FiniteSet";
            if len(losning_set) == 1: los_ant = "en løsning"
            if len(losning_set) > 1: los_ant = str(len(losning_set)) + " " + "løsninger"

        if len(likning) == 0 and type(losning_set) == ConditionSet:
            sett_typ = "ConditionSet"; losning_element = nsolve(_likning, variabel, 1)
            los_ant = "en numerisk løsning"; losning_set = []; losning_set.append(losning_element)

        if len(likning) == 0 and type(losning_set) == Intersection:
            sett_typ = "Intersection"; losning_set_sub = losning_set.args[1]
            losning_element = losning_set_sub.args; losning_set = [];
            for el in losning_element: losning_set.append(el); rund = -1
            if len(losning_set) == 1: los_ant = "en løsning som er et uttrykk"
            if len(losning_set) > 1: los_ant = str(len(losning_set)) + " " + "løsninger som er uttrykk"

    if len(likning) > 0:
        sett_typ = ""; likn_ant = "Flere likninger (likningssett)"
        losning_set = solve(likning, variabel, dict=True)
        for i in range(len(losning_set)):
            koordinat_verdi_liste = list(); koordinat_variabel_rund_liste = list()
            for koordinat_variabel, koordinat_verdi in losning_set[i].items():
                koordinat_verdi_liste.append(koordinat_verdi)
                losning_rund = round(float(koordinat_verdi), rund)
                koordinat_variabel_rund_liste.append(losning_rund)
            losning_liste.append(koordinat_verdi_liste); losning_rund_liste.append(koordinat_variabel_rund_liste)

    for losning in losning_set:
        if rund == -1:
            _v_avrund_typ = "(eksakt)"; losning_rund_status = "Nei"; losning_rund_liste = ""
            if len(likning) == 0: losning_liste.append(losning); losning_ut = losning_liste
            if len(likning) > 0: losning_ut = losning_liste

        if rund != -1:
            _v_avrund_typ = "(avrundet)"; losning_rund_status = "Ja"
            if len(likning) == 0:
                losning_liste.append(losning); losning_rund = round(losning, rund)
                losning_rund_liste.append(losning_rund); losning_ut = losning_rund_liste
            if len(likning) > 0: losning_ut = losning_rund_liste

    if len(losning_ut) == 1: losning_ut = losning_ut[0]

    if debug == 1:
        print("")
        print(f"*** Debug ****")
        if vis_datatype == True:
            print(f"Data-type                        :: {sett_typ}")
        print(f"Løsnings-type                    :: {likn_ant} med {los_ant} {_v_avrund_typ}")
        print(f"Løsnings-sett                    :: {losning_set}")
        print(f"Løsnings-element(er)             :: {losning_liste}")
        print(f"Avrunding (ja/nei)               :: {losning_rund_status}")
        print(f"Løsnings-elemente(er) avrundet   :: {losning_rund_liste}")
        print(f"-----------------------------------")
        print(f"Løsning ut (returnert) -----------> {losning_ut}")
        print(f"-----------------------------------")

    return losning_ut

def ekstremalpunkt(variabel = Symbol(""),
                   f        = Symbol(""),
                   rund     = -1,
                   debug    = -1):

    # Deriverer funksjonen f mhp.  og får 
    df = diff(f, x)

    # Løser likningen df = 0 
    f_ekstremalpunkt = superløs(variabel = variabel,
                                vs       = df,
                                hs       = 0,
                                rund     = rund,
                                debug    = debug)

    return f_ekstremalpunkt

# Konstanter
_blokk = 1 # 0: Av, 1: På, Skjul/debug deler av koden med if-blokker

# a) Påstand 1: Grafen f har minst ett ekstremalpunkt
if _blokk == 1:

    # Konstanter og CAS-variabler (symbol)
    a                  = Symbol("a")   # Funksjonens a-koeffisient
    b                  = Symbol("b")   # Funksjonens b-koeffisient
    c                  = Symbol("c")   # Funksjonens c-koeffisient
    d                  = Symbol("d")   # Funksjonens c-koeffisient
    f                  = Symbol("f")   # Funksjonens navn
    x                  = Symbol("f")   # Funksjonens variabel

    # Svar-setninger
    svar_a_liste = list()
    svar_a_liste.append(f"")
    svar_a_liste.append(f"Oppg a)")
    svar_a_liste.append(f"")
    svar_a_liste.append(f"- Hvis alle tredjegradsfunksjoner har minst ett ekstremalpunkt,")
    svar_a_liste.append(f"  så kan vi først finne uttrykket til ekstremalpunktene")
    svar_a_liste.append(f"- Dette finner vi ved å")
    svar_a_liste.append(f"  1. Definere et generelt uttryk for f")
    svar_a_liste.append(f"  2. Derivere f")
    svar_a_liste.append(f"  3. Løse likningen df = 0")
    svar_a_liste.append(f"  4. Løsningen på df = 0 vil være evt. ekstremalpunkt")
    svar_a_liste.append(f"  5. Se om vi kan trekke noen konklusjoner fra løsningen")

    # Definerer uttrykket for f
    f = a * x**3 + b * x**2 + c * x + d

    # Finner ekstremalpunktene til f(x) = a * x**3 + b * x**2 + c * x + d
    f_ekstremalpunkt = ekstremalpunkt(variabel = x,
                                      f        = a * x**3 + b * x**2 + c * x + d,
                                      rund     = -1,
                                      debug    = -1)

    # Printer løsningene -b/(3*a) ± sqrt(-3*a*c + b**2)/(3*a)
    svar_a_liste.append(f"")
    svar_a_liste.append(f"- Ekstremalpunktene til f er:")
    for i in range(len(f_ekstremalpunkt)):
        svar_a_liste.append(f"  - ekstremalpunkt_{i} = {f_ekstremalpunkt[i]}")

    # Svar-setninger
    svar_a_liste.append(f"")
    svar_a_liste.append(f"- Når uttrykket under rot-tegnet (diskriminanten, -3*a*c + b**2)")
    svar_a_liste.append(f"  er negativt, så har likningen df = 0 ingen løsning")
    svar_a_liste.append(f"- Dette betyr igjen betyr at slike funksjoner ikke har")
    svar_a_liste.append(f"  noen ekstremalpunkter")
    svar_a_liste.append(f"- Vi kan også uttrykke en negativ diskrimant med ulikheten")
    svar_a_liste.append(f"  -3*a*c + b**2 < 0")
    svar_a_liste.append(f"- Deretter kan vi løse denne ulikheten for f.eks. a for å")
    svar_a_liste.append(f"  vise sammenhengen mellom a og de andre to koeffisientene, b og c")
    svar_a_liste.append(f"- Eller, vi kan gjøre det samme for f.eks. b (og vise")
    svar_a_liste.append(f"  sammenhengen mellom b og de to andre koeffisientene, a og c")
    svar_a_liste.append(f"- Dette er altså kun for bedre å vise sammenhengen")
    svar_a_liste.append(f"  mellom de tre koeffisientene, istedenfor å bare vise en uliket")
    svar_a_liste.append(f"- NB: Passer på at ulikhets-tegnet peker riktig vei når vi først løser")
    svar_a_liste.append(f"- en slik likning, for så å konverterer løsningen tilbake til en ulikhet")

    # Løser likningen -3*a*c + b**2 = 0 for a
    a_uttrykk = superløs(variabel = a,
                         vs       = -3*a*c + b**2,
                         hs       = 0,
                         rund     = -1,
                         debug    = -1)

    # Svar-setninger
    svar_a_liste.append(f"")
    svar_a_liste.append(f"- Som vi ser, så finnes det tredjegradsfunksjoner som ikke har minst")
    svar_a_liste.append(f"  ett ekstremalpunkt")
    svar_a_liste.append(f"- Mer bestemt, så vil alle tredjegradsfunksjoner hvor")
    svar_a_liste.append(f" {a} > {a_uttrykk} ikke ha noen ekstremalpunkt")
    svar_a_liste.append(f"")
    svar_a_liste.append(f"- Påstand 1 er derfor usann")

    # Print svar-setninger
    for svar in svar_a_liste: print(svar)



# 🚀 programmering.no | 🤓 matematikk.as
# S1 - Eksamen - 2023 Høst (Matematikk AS)
# Oppgave 5 a) Volum av prisme - Største volum dersom sidene i bunnen er 5 dm (løsning med likninger) 

from sympy import Eq, Reals, Symbol, solveset

# Konstanter
_blokk = 1 # 0: Av, 1: På, Skjul/debug deler av koden med if-blokker

# Definerer funksjoner
def los_sett(variabel = Symbol(""),
             vs       = Symbol(""),
             hs       = Symbol(""),
             rund     = None):

    # Lager likningen med Eq(vs, hs) 
    likning = Eq(vs, hs)

    # Løser likningen for aktuell variabel med solveset() og får løsnings-settet på formen {1234.56789}
    losning_set = solveset(likning, variabel, domain = Reals) # Løsnings-domene i ℝ (Reals)

    # Henter elementet i fra løsnings-settet, f.eks. 1234.56789
    losning = losning_set.args[0] # [0] er første element (det eneste her)

    # Runder av f.eks. 1234.56789 -> 1234.6
    losning = round(losning, rund)

    return losning

# a) Største volum dersom sidene i bunnen er 5 dm (løsning med likninger)
if _blokk == 1:

    # Regner ut volum av prisme med likning når areal_maks, lengde og dybde er gitt

    # Skisse av kassen
    if _blokk == 0:
        #                    |------------
        #                    | .	       .
        #                    |  -	   V    -
        #                    |   .------------
        #                    _   |			 |
        #                     .  |	   A     |   h
        #                 s     _|			 |
        #                        .------------
        # 
        #                                s
        pass

    # Konstanter og CAS-variabler (symbol)
    V                  = Symbol("V")   # Prismets volum
    A                  = Symbol("A")   # Arealet av platene
    A_max          = 120           # Maksimalt arealet av platene
    s                  = Symbol("s")   # Sidene i den kvadratiske grunnflaten
    s_5                = 5             # Lengden på sidene
    h                  = Symbol("h")   # Prismets høyde

    # Definerer uttrykkene for A og V
    A = s**2 + 4*s*h
    V = s**2 * h

    # Setter s = 5 inn i A og definerer det nye uttrykket som A_5 (slik at ikke A skrives over) 
    A_5 = A.subs(s, s_5)

    # Løser likningen 120 = 5**2 + 4*5*h 
    h_losning = los_sett(vs       = A_max,
                         hs       = A_5,
                         variabel = h,
                         rund     = 2)

    # Setter h = -(s + 5)/4 inn i V og definerer det nye uttrykket som V_uttrykk 
    V_max = V.subs(s, s_5).subs(h, h_losning) # Bruker .subs flere ganger etter hverandre ("chain rule")

    # Print svar-setninger
    svar_a_0 = f"Oppg a)"
    svar_a_1 = f"- Det største volumet kassen kan ha er {V_max} dm^3"
    print("")
    print(svar_a_0)
    print(svar_a_1)



# 🚀 programmering.no | 🤓 matematikk.as
# - Regn ut summen av de n første kvadratene i rekken

# Verdier
n = 12

# Sum-funksjon for n kvadrater
def rekke_n_kvadrater_sum(n):

    # Type cast inp-str -> int
    n = int(n)

    # Formel for sum av n kvadrater
    sum = int((n * (n + 1) * (2 * n + 1)) / 6)

    return sum

# Summer n kvadrater
sum = rekke_n_kvadrater_sum(n)

# Print
print(f"Summen av de {n} første kvadratene er: {sum}")
